pub struct LoginSuccessResponse {
pub access_token: String,
pub expires_in: u64,
pub expires_at: i64,
pub scope: String,
pub token_type: String,
pub refresh_token: Option<String>,
pub user_key_wrapped_user_private_key: Option<String>,
pub two_factor_token: Option<String>,
pub force_password_reset: Option<bool>,
pub api_use_key_connector: Option<bool>,
pub user_decryption_options: UserDecryptionOptionsResponse,
pub master_password_policy: Option<MasterPasswordPolicyResponse>,
}Expand description
SDK response model for a successful login. This is the model that will be exposed to consuming applications.
Fields
access_token: StringThe access token string.
expires_in: u64The duration in seconds until the token expires.
expires_at: i64The timestamp in milliseconds when the token expires. We calculate this for more convenient token expiration handling.
scope: StringThe scope of the access token. OAuth 2.0 RFC reference: https://datatracker.ietf.org/doc/html/rfc6749#section-3.3
token_type: StringThe type of the token. This will be “Bearer” for send access tokens. OAuth 2.0 RFC reference: https://datatracker.ietf.org/doc/html/rfc6749#section-7.1
refresh_token: Option<String>The optional refresh token string. This token can be used to obtain new access tokens when the current one expires.
user_key_wrapped_user_private_key: Option<String>The user key wrapped user private key. Note: previously known as “private_key”.
two_factor_token: Option<String>Two-factor authentication token for future requests.
force_password_reset: Option<bool>Indicates whether an admin has reset the user’s master password, requiring them to set a new password upon next login.
api_use_key_connector: Option<bool>Indicates whether the user uses Key Connector and if the client should have a locally configured Key Connector URL in their environment. Note: This is currently only applicable for client_credential grant type logins and is only expected to be relevant for the CLI
user_decryption_options: UserDecryptionOptionsResponseThe user’s decryption options for unlocking their vault.
master_password_policy: Option<MasterPasswordPolicyResponse>If the user is subject to an organization master password policy, this field contains the requirements of that policy.